.. Fritter documentation master file, created by
   sphinx-quickstart on Tue Aug 15 17:22:48 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Fritter's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   quickstart
   civil
   trees
   repeat
   persistence
   api/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
